@@ -2,7 +2,7 @@ use crate::monotonic::Monotonic;
 use crate::scalar::Scalar;
 use crate::segment::{BoundingRect, Segment};
 use crate::traits::Transformation;
-use crate::{rect, Point, Rect, Vector};
+use crate::{Point, Rect, Vector, Box2D, point};
 use crate::{CubicBezierSegment, Line, LineEquation, LineSegment, Triangle};
 use arrayvec::ArrayVec;
 
@@ -448,14 +448,19 @@ impl<S: Scalar> QuadraticBezierSegment<S> {
     }
 
     /// Returns a conservative rectangle that contains the curve.
-    pub fn fast_bounding_rect(&self) -> Rect<S> {
+    pub fn fast_bounding_box(&self) -> Box2D<S> {
         let (min_x, max_x) = self.fast_bounding_range_x();
         let (min_y, max_y) = self.fast_bounding_range_y();
 
-        rect(min_x, min_y, max_x - min_x, max_y - min_y)
+        Box2D { min: point(min_x, min_y), max: point(max_x, max_y) }
     }
 
-    /// Returns a conservative range of x this curve is contained in.
+    /// Returns a conservative rectangle that contains the curve.
+    pub fn fast_bounding_rect(&self) -> Rect<S> {
+        self.fast_bounding_box().to_rect()
+    }
+
+    /// Returns a conservative range of x that contains this curve.
     pub fn fast_bounding_range_x(&self) -> (S, S) {
         let min_x = self.from.x.min(self.ctrl.x).min(self.to.x);
         let max_x = self.from.x.max(self.ctrl.x).max(self.to.x);
@@ -463,7 +468,7 @@ impl<S: Scalar> QuadraticBezierSegment<S> {
         (min_x, max_x)
     }
 
-    /// Returns a conservative range of y this curve is contained in.
+    /// Returns a conservative range of y that contains this curve.
     pub fn fast_bounding_range_y(&self) -> (S, S) {
         let min_y = self.from.y.min(self.ctrl.y).min(self.to.y);
         let max_y = self.from.y.max(self.ctrl.y).max(self.to.y);
@@ -472,14 +477,19 @@ impl<S: Scalar> QuadraticBezierSegment<S> {
     }
 
     /// Returns the smallest rectangle the curve is contained in
-    pub fn bounding_rect(&self) -> Rect<S> {
+    pub fn bounding_box(&self) -> Box2D<S> {
         let (min_x, max_x) = self.bounding_range_x();
         let (min_y, max_y) = self.bounding_range_y();
 
-        rect(min_x, min_y, max_x - min_x, max_y - min_y)
+        Box2D { min: point(min_x, min_y), max: point(max_x, max_y) }
     }
 
-    /// Returns the smallest range of x this curve is contained in.
+    /// Returns the smallest rectangle the curve is contained in
+    pub fn bounding_rect(&self) -> Rect<S> {
+        self.bounding_box().to_rect()
+    }
+
+    /// Returns the smallest range of x that contains this curve.
     pub fn bounding_range_x(&self) -> (S, S) {
         let min_x = self.x(self.x_minimum_t());
         let max_x = self.x(self.x_maximum_t());
@@ -487,7 +497,7 @@ impl<S: Scalar> QuadraticBezierSegment<S> {
         (min_x, max_x)
     }
 
-    /// Returns the smallest range of y this curve is contained in.
+    /// Returns the smallest range of y that contains this curve.
     pub fn bounding_range_y(&self) -> (S, S) {
         let min_y = self.y(self.y_minimum_t());
         let max_y = self.y(self.y_maximum_t());
@@ -798,6 +808,9 @@ impl<S: Scalar> BoundingRect for QuadraticBezierSegment<S> {
 /// A monotonically increasing in x and y quadratic bézier curve segment
 pub type MonotonicQuadraticBezierSegment<S> = Monotonic<QuadraticBezierSegment<S>>;
 
+#[cfg(test)]
+use crate::rect;
+
 #[test]
 fn bounding_rect_for_monotonic_quadratic_bezier_segment() {
     let a = QuadraticBezierSegment {
